*******
Credits
*******

Acknowledgments
===============
AE Studio

Authors
=======
Sumner L Norman (@sumner15)
Darin Erat Sleiter (@dsleiter)
José Ribeiro (@ribeirojose)

Contributors
============
Ben Dichter (@bendichter)
Rob Luke (@rob-luke)

*****
Legal
*****

License
=======
